A package which adds extra widgets to CustomTKinter\
See the code on [github](https://github.com/TonyLovesCoding/CTkAddons).

> [!WARNING]\
> This project is **EXTREMELY** early in development\
> Proceed with caution!

# CTkCalender

It's a calender... duh...\
Use `ctkaddons.CTkCalender()`

# Side Panel

It's a side panel\
Use `ctkaddons.CTkSidePanel()` to create a side panel

If you want to add a scene, use `side_panel.add_scene()`, remember to pass in a key

# Date Picker
`ctkaddons.CTkDateSelect()`